@@ -21,14 +21,16 @@ import matplotlib.pyplot as plt
 
 class Client():
 
-    def __init__(self,api_key,dev=False):
+    def __init__(self,api_key,verbose=False,dev=False):
 
         def invert_dict(to_invert):
             return {v:k for k,v in to_invert.items()}
 
-        static.initialize()
         self.api_url = API_URL
         self.api_key = api_key
+        self.verbose = verbose
+
+        static.initialize(self.verbose)
         
         if dev:
             self.api_key = EQUITIES_PUBLIC_API_KEY
@@ -39,7 +41,7 @@ class Client():
             self.cik_to_ticker = self._fetch_cik_to_ticker_map()
             self.name_to_cik = invert_dict(self.cik_to_name)
             self.ticker_to_cik = invert_dict(self.cik_to_ticker)
-            static.initialized()
+            static.initialized(self.verbose)
         except Exception as e:
             static.failed()
             print("Exception: %s"%str(e))
@@ -93,12 +95,12 @@ class Client():
         return self.ticker_to_cik[ticker.lower().replace(' ','')]
 
     def dataset(self,name):
-        static.dataset(name)
+        static.dataset(self.verbose,name)
         query = gql.gql(DATASET_QUERY(name,self.api_key))
         return self.graphql.execute(query)['dataset'][0]
 
     def datasets(self):
-        static.datasets()
+        static.datasets(self.verbose)
         return list(self._fetch_dataset_to_desc_map().keys())
 
     def company(self,ticker_or_cik,df=False):
@@ -112,7 +114,7 @@ class Client():
         else:
             cik = ticker_or_cik
         
-        static.company(cik)
+        static.company(self.verbose,cik)
         query = gql.gql(COMPANY_QUERY(cik,self.api_key))
         data = self.graphql.execute(query)['company'][0]
         if df: 
@@ -123,15 +125,15 @@ class Client():
         return COMPANY_SCHEMA(data)
 
     def ciks(self):
-        static.companies()
+        static.companies(self.verbose)
         return list(self.cik_to_name.keys())
 
     def company_names(self):
-        static.companies()
+        static.companies(self.verbose)
         return list(self.name_to_cik.keys())
         
     def financial_statement(self,cik,kind,df=False):
-        static.financial_statement(self.cik_to_name[cik],kind)
+        static.financial_statement(self.verbose,self.cik_to_name[cik],kind)
         query = gql.gql(FINANCIAL_STATEMENT_QUERY(cik,kind,self.api_key))
         statement = self.graphql.execute(query)['company'][0][kind]
         statement = pd.DataFrame.from_dict(json.loads(statement))
